# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/mfcc-buffer/mfcc-buffer-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/mfcc-buffer/mfcc-buffer-service.proto',
  package='ai.cogneed.api.predict.mfccbuffer',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n<cogneed-protos/predict/mfcc-buffer/mfcc-buffer-service.proto\x12!ai.cogneed.api.predict.mfccbuffer\"\"\n\x12MfccBufferResponse\x12\x0c\n\x04mfcc\x18\x01 \x01(\x0c\"F\n\x11MfccBufferRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x32\x8c\x01\n\x11MfccBufferService\x12w\n\x08get_mfcc\x12\x34.ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest\x1a\x35.ai.cogneed.api.predict.mfccbuffer.MfccBufferResponseb\x06proto3')
)




_MFCCBUFFERRESPONSE = _descriptor.Descriptor(
  name='MfccBufferResponse',
  full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mfcc', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferResponse.mfcc', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=133,
)


_MFCCBUFFERREQUEST = _descriptor.Descriptor(
  name='MfccBufferRequest',
  full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest.index', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=205,
)

DESCRIPTOR.message_types_by_name['MfccBufferResponse'] = _MFCCBUFFERRESPONSE
DESCRIPTOR.message_types_by_name['MfccBufferRequest'] = _MFCCBUFFERREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MfccBufferResponse = _reflection.GeneratedProtocolMessageType('MfccBufferResponse', (_message.Message,), dict(
  DESCRIPTOR = _MFCCBUFFERRESPONSE,
  __module__ = 'cogneed_protos.predict.mfcc_buffer.mfcc_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.mfccbuffer.MfccBufferResponse)
  ))
_sym_db.RegisterMessage(MfccBufferResponse)

MfccBufferRequest = _reflection.GeneratedProtocolMessageType('MfccBufferRequest', (_message.Message,), dict(
  DESCRIPTOR = _MFCCBUFFERREQUEST,
  __module__ = 'cogneed_protos.predict.mfcc_buffer.mfcc_buffer_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.mfccbuffer.MfccBufferRequest)
  ))
_sym_db.RegisterMessage(MfccBufferRequest)



_MFCCBUFFERSERVICE = _descriptor.ServiceDescriptor(
  name='MfccBufferService',
  full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=208,
  serialized_end=348,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_mfcc',
    full_name='ai.cogneed.api.predict.mfccbuffer.MfccBufferService.get_mfcc',
    index=0,
    containing_service=None,
    input_type=_MFCCBUFFERREQUEST,
    output_type=_MFCCBUFFERRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MFCCBUFFERSERVICE)

DESCRIPTOR.services_by_name['MfccBufferService'] = _MFCCBUFFERSERVICE

# @@protoc_insertion_point(module_scope)
