# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.modelconfig import model_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2


class ModelServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Create',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.CreateRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.List = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/List',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.FromString,
        )
    self.Read = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Read',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.FromString,
        )
    self.Upgrade = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Upgrade',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
        )
    self.StartTraining = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/StartTraining',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.Deploy = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/Deploy',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.MarkAsTrained = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.model.ModelService/MarkAsTrained',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class ModelServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Create(self, request, context):
    """Create a new model
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """List all models from a given algorithm
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Read(self, request, context):
    """Fetch data from a given model
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Upgrade(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartTraining(self, request, context):
    """Start training the given model
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Deploy(self, request, context):
    """Use this model in prod
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarkAsTrained(self, request, context):
    """Mark the given model as trained
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ModelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.CreateRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ListResponse.SerializeToString,
      ),
      'Read': grpc.unary_unary_rpc_method_handler(
          servicer.Read,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.Model.SerializeToString,
      ),
      'Upgrade': grpc.unary_unary_rpc_method_handler(
          servicer.Upgrade,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.SerializeToString,
      ),
      'StartTraining': grpc.unary_unary_rpc_method_handler(
          servicer.StartTraining,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'Deploy': grpc.unary_unary_rpc_method_handler(
          servicer.Deploy,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'MarkAsTrained': grpc.unary_unary_rpc_method_handler(
          servicer.MarkAsTrained,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_model__pb2.ModelUuid.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.modelconfig.model.ModelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
