# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/trainui/record.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/trainui/record.proto',
  package='ai.cogneed.api.trainui.record',
  syntax='proto3',
  serialized_options=_b('\n\035ai.cogneed.api.trainui.recordP\001'),
  serialized_pb=_b('\n2cogneed-protos/ai/cogneed/api/trainui/record.proto\x12\x1d\x61i.cogneed.api.trainui.record\x1a*cogneed-protos/ai/cogneed/api/common.proto\"p\n\x06\x43reate\x12\x15\n\rsentence_uuid\x18\x01 \x01(\t\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x05\x12\x14\n\x0cnum_channels\x18\x03 \x01(\x05\x12\x13\n\x0bsample_size\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\"!\n\nRecordUuid\x12\x13\n\x0brecord_uuid\x18\x01 \x01(\t\"\x1e\n\x0bRecordAudio\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\xec\x01\n\x06Record\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\rsentence_uuid\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\x12\x10\n\x08start_ms\x18\x05 \x01(\x05\x12\x0e\n\x06\x65nd_ms\x18\x06 \x01(\x05\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\x03\x12\x12\n\nupdated_at\x18\n \x01(\x03\x12\x39\n\x05state\x18\x0b \x01(\x0e\x32*.ai.cogneed.api.trainui.record.RecordState\"]\n\x0e\x45nhancedRecord\x12\x35\n\x06record\x18\x01 \x01(\x0b\x32%.ai.cogneed.api.trainui.record.Record\x12\x14\n\x0ckeyword_name\x18\x02 \x01(\t\"H\n\x16\x45xtractValidateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x10\n\x08start_ms\x18\x02 \x01(\x05\x12\x0e\n\x06\x65nd_ms\x18\x03 \x01(\x05\"n\n\x0bListRecords\x12:\n\x06states\x18\x01 \x03(\x0e\x32*.ai.cogneed.api.trainui.record.RecordState\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x15\n\rrows_per_page\x18\x03 \x01(\x05\"d\n\x13ListRecordsResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12>\n\x07records\x18\x02 \x03(\x0b\x32-.ai.cogneed.api.trainui.record.EnhancedRecord*5\n\x0bRecordState\x12\x08\n\x04INIT\x10\x00\x12\r\n\tEXTRACTED\x10\x01\x12\r\n\tVALIDATED\x10\x02\x32\xbd\x04\n\rRecordService\x12L\n\x06\x63reate\x12%.ai.cogneed.api.trainui.record.Create\x1a\x1b.ai.cogneed.api.AckResponse\x12\x63\n\nread_audio\x12).ai.cogneed.api.trainui.record.RecordUuid\x1a*.ai.cogneed.api.trainui.record.RecordAudio\x12X\n\x04read\x12).ai.cogneed.api.trainui.record.RecordUuid\x1a%.ai.cogneed.api.trainui.record.Record\x12\x66\n\x04list\x12*.ai.cogneed.api.trainui.record.ListRecords\x1a\x32.ai.cogneed.api.trainui.record.ListRecordsResponse\x12P\n\x06\x64\x65lete\x12).ai.cogneed.api.trainui.record.RecordUuid\x1a\x1b.ai.cogneed.api.AckResponse\x12\x65\n\x0f\x45xtractValidate\x12\x35.ai.cogneed.api.trainui.record.ExtractValidateRequest\x1a\x1b.ai.cogneed.api.AckResponseB!\n\x1d\x61i.cogneed.api.trainui.recordP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])

_RECORDSTATE = _descriptor.EnumDescriptor(
  name='RecordState',
  full_name='ai.cogneed.api.trainui.record.RecordState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTRACTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=932,
  serialized_end=985,
)
_sym_db.RegisterEnumDescriptor(_RECORDSTATE)

RecordState = enum_type_wrapper.EnumTypeWrapper(_RECORDSTATE)
INIT = 0
EXTRACTED = 1
VALIDATED = 2



_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='ai.cogneed.api.trainui.record.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sentence_uuid', full_name='ai.cogneed.api.trainui.record.Create.sentence_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='ai.cogneed.api.trainui.record.Create.sample_rate', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_channels', full_name='ai.cogneed.api.trainui.record.Create.num_channels', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_size', full_name='ai.cogneed.api.trainui.record.Create.sample_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.trainui.record.Create.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=241,
)


_RECORDUUID = _descriptor.Descriptor(
  name='RecordUuid',
  full_name='ai.cogneed.api.trainui.record.RecordUuid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record_uuid', full_name='ai.cogneed.api.trainui.record.RecordUuid.record_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=276,
)


_RECORDAUDIO = _descriptor.Descriptor(
  name='RecordAudio',
  full_name='ai.cogneed.api.trainui.record.RecordAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.trainui.record.RecordAudio.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=308,
)


_RECORD = _descriptor.Descriptor(
  name='Record',
  full_name='ai.cogneed.api.trainui.record.Record',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.record.Record.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sentence_uuid', full_name='ai.cogneed.api.trainui.record.Record.sentence_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='ai.cogneed.api.trainui.record.Record.duration', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.api.trainui.record.Record.start_ms', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.api.trainui.record.Record.end_ms', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='ai.cogneed.api.trainui.record.Record.created_by', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_by', full_name='ai.cogneed.api.trainui.record.Record.updated_by', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='ai.cogneed.api.trainui.record.Record.created_at', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='ai.cogneed.api.trainui.record.Record.updated_at', index=8,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ai.cogneed.api.trainui.record.Record.state', index=9,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=547,
)


_ENHANCEDRECORD = _descriptor.Descriptor(
  name='EnhancedRecord',
  full_name='ai.cogneed.api.trainui.record.EnhancedRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='ai.cogneed.api.trainui.record.EnhancedRecord.record', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_name', full_name='ai.cogneed.api.trainui.record.EnhancedRecord.keyword_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=642,
)


_EXTRACTVALIDATEREQUEST = _descriptor.Descriptor(
  name='ExtractValidateRequest',
  full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest.start_ms', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.api.trainui.record.ExtractValidateRequest.end_ms', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=716,
)


_LISTRECORDS = _descriptor.Descriptor(
  name='ListRecords',
  full_name='ai.cogneed.api.trainui.record.ListRecords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='states', full_name='ai.cogneed.api.trainui.record.ListRecords.states', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='ai.cogneed.api.trainui.record.ListRecords.page', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows_per_page', full_name='ai.cogneed.api.trainui.record.ListRecords.rows_per_page', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=828,
)


_LISTRECORDSRESPONSE = _descriptor.Descriptor(
  name='ListRecordsResponse',
  full_name='ai.cogneed.api.trainui.record.ListRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='ai.cogneed.api.trainui.record.ListRecordsResponse.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='records', full_name='ai.cogneed.api.trainui.record.ListRecordsResponse.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=930,
)

_RECORD.fields_by_name['state'].enum_type = _RECORDSTATE
_ENHANCEDRECORD.fields_by_name['record'].message_type = _RECORD
_LISTRECORDS.fields_by_name['states'].enum_type = _RECORDSTATE
_LISTRECORDSRESPONSE.fields_by_name['records'].message_type = _ENHANCEDRECORD
DESCRIPTOR.message_types_by_name['Create'] = _CREATE
DESCRIPTOR.message_types_by_name['RecordUuid'] = _RECORDUUID
DESCRIPTOR.message_types_by_name['RecordAudio'] = _RECORDAUDIO
DESCRIPTOR.message_types_by_name['Record'] = _RECORD
DESCRIPTOR.message_types_by_name['EnhancedRecord'] = _ENHANCEDRECORD
DESCRIPTOR.message_types_by_name['ExtractValidateRequest'] = _EXTRACTVALIDATEREQUEST
DESCRIPTOR.message_types_by_name['ListRecords'] = _LISTRECORDS
DESCRIPTOR.message_types_by_name['ListRecordsResponse'] = _LISTRECORDSRESPONSE
DESCRIPTOR.enum_types_by_name['RecordState'] = _RECORDSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(
  DESCRIPTOR = _CREATE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.Create)
  ))
_sym_db.RegisterMessage(Create)

RecordUuid = _reflection.GeneratedProtocolMessageType('RecordUuid', (_message.Message,), dict(
  DESCRIPTOR = _RECORDUUID,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.RecordUuid)
  ))
_sym_db.RegisterMessage(RecordUuid)

RecordAudio = _reflection.GeneratedProtocolMessageType('RecordAudio', (_message.Message,), dict(
  DESCRIPTOR = _RECORDAUDIO,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.RecordAudio)
  ))
_sym_db.RegisterMessage(RecordAudio)

Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), dict(
  DESCRIPTOR = _RECORD,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.Record)
  ))
_sym_db.RegisterMessage(Record)

EnhancedRecord = _reflection.GeneratedProtocolMessageType('EnhancedRecord', (_message.Message,), dict(
  DESCRIPTOR = _ENHANCEDRECORD,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.EnhancedRecord)
  ))
_sym_db.RegisterMessage(EnhancedRecord)

ExtractValidateRequest = _reflection.GeneratedProtocolMessageType('ExtractValidateRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTVALIDATEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.ExtractValidateRequest)
  ))
_sym_db.RegisterMessage(ExtractValidateRequest)

ListRecords = _reflection.GeneratedProtocolMessageType('ListRecords', (_message.Message,), dict(
  DESCRIPTOR = _LISTRECORDS,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.ListRecords)
  ))
_sym_db.RegisterMessage(ListRecords)

ListRecordsResponse = _reflection.GeneratedProtocolMessageType('ListRecordsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRECORDSRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.record_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.record.ListRecordsResponse)
  ))
_sym_db.RegisterMessage(ListRecordsResponse)


DESCRIPTOR._options = None

_RECORDSERVICE = _descriptor.ServiceDescriptor(
  name='RecordService',
  full_name='ai.cogneed.api.trainui.record.RecordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=988,
  serialized_end=1561,
  methods=[
  _descriptor.MethodDescriptor(
    name='create',
    full_name='ai.cogneed.api.trainui.record.RecordService.create',
    index=0,
    containing_service=None,
    input_type=_CREATE,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='read_audio',
    full_name='ai.cogneed.api.trainui.record.RecordService.read_audio',
    index=1,
    containing_service=None,
    input_type=_RECORDUUID,
    output_type=_RECORDAUDIO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='read',
    full_name='ai.cogneed.api.trainui.record.RecordService.read',
    index=2,
    containing_service=None,
    input_type=_RECORDUUID,
    output_type=_RECORD,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='list',
    full_name='ai.cogneed.api.trainui.record.RecordService.list',
    index=3,
    containing_service=None,
    input_type=_LISTRECORDS,
    output_type=_LISTRECORDSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='delete',
    full_name='ai.cogneed.api.trainui.record.RecordService.delete',
    index=4,
    containing_service=None,
    input_type=_RECORDUUID,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ExtractValidate',
    full_name='ai.cogneed.api.trainui.record.RecordService.ExtractValidate',
    index=5,
    containing_service=None,
    input_type=_EXTRACTVALIDATEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECORDSERVICE)

DESCRIPTOR.services_by_name['RecordService'] = _RECORDSERVICE

# @@protoc_insertion_point(module_scope)
