# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.predict.labelmapper import labelmapper_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2


class LabelMapperServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Convert = channel.unary_unary(
        '/ai.cogneed.api.predict.labelmapper.LabelMapperService/Convert',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertResponse.FromString,
        )


class LabelMapperServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Convert(self, request, context):
    """Retrieve the associate label to the given prediction index.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_LabelMapperServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Convert': grpc.unary_unary_rpc_method_handler(
          servicer.Convert,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_labelmapper_dot_labelmapper__pb2.ConvertResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.predict.labelmapper.LabelMapperService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
