# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/common.proto',
  package='ai.cogneed.api.audio',
  syntax='proto3',
  serialized_options=_b('\n\024ai.cogneed.api.audioP\001'),
  serialized_pb=_b('\n0cogneed-protos/ai/cogneed/api/audio/common.proto\x12\x14\x61i.cogneed.api.audio\"\xa8\x01\n\x0b\x41udioFormat\x12+\n\x03\x65xt\x18\x01 \x01(\x0e\x32\x1e.ai.cogneed.api.audio.AudioExt\x12/\n\x05\x63odec\x18\x02 \x01(\x0e\x32 .ai.cogneed.api.audio.AudioCodec\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x03\x12\x10\n\x08\x63hannels\x18\x04 \x01(\x05\x12\x14\n\x0csample_width\x18\x05 \x01(\x05\"9\n\x11\x44\x65tectionResponse\x12\x13\n\x0bmillisecond\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"W\n\x19OptionalDetectionResponse\x12:\n\tdetection\x18\x01 \x01(\x0b\x32\'.ai.cogneed.api.audio.DetectionResponse\"\x1c\n\tAudioBlob\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"(\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t*8\n\x08\x41udioExt\x12\x08\n\x04WEBM\x10\x00\x12\x07\n\x03MP3\x10\x01\x12\x07\n\x03WAV\x10\x02\x12\x07\n\x03OGG\x10\x03\x12\x07\n\x03RAW\x10\x04*g\n\nAudioCodec\x12\x08\n\x04OPUS\x10\x00\x12\n\n\x06VORBIS\x10\x01\x12\x0e\n\nSIGNED_PCM\x10\x02\x12\x10\n\x0cUNSIGNED_PCM\x10\x03\x12\r\n\tFLOAT_PCM\x10\x04\x12\x08\n\x04ULAW\x10\x05\x12\x08\n\x04\x41LAW\x10\x06*Z\n\x11PersistenceConfig\x12\x15\n\x11RECORD_FULL_AUDIO\x10\x00\x12\x1a\n\x16RECORD_DETECTION_BLOBS\x10\x01\x12\x12\n\x0eRECORD_NOTHING\x10\x02\x42\x18\n\x14\x61i.cogneed.api.audioP\x01\x62\x06proto3')
)

_AUDIOEXT = _descriptor.EnumDescriptor(
  name='AudioExt',
  full_name='ai.cogneed.api.audio.AudioExt',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEBM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP3', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAV', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OGG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAW', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=465,
  serialized_end=521,
)
_sym_db.RegisterEnumDescriptor(_AUDIOEXT)

AudioExt = enum_type_wrapper.EnumTypeWrapper(_AUDIOEXT)
_AUDIOCODEC = _descriptor.EnumDescriptor(
  name='AudioCodec',
  full_name='ai.cogneed.api.audio.AudioCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPUS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VORBIS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNED_PCM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSIGNED_PCM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT_PCM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ULAW', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALAW', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=523,
  serialized_end=626,
)
_sym_db.RegisterEnumDescriptor(_AUDIOCODEC)

AudioCodec = enum_type_wrapper.EnumTypeWrapper(_AUDIOCODEC)
_PERSISTENCECONFIG = _descriptor.EnumDescriptor(
  name='PersistenceConfig',
  full_name='ai.cogneed.api.audio.PersistenceConfig',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RECORD_FULL_AUDIO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORD_DETECTION_BLOBS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORD_NOTHING', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=628,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_PERSISTENCECONFIG)

PersistenceConfig = enum_type_wrapper.EnumTypeWrapper(_PERSISTENCECONFIG)
WEBM = 0
MP3 = 1
WAV = 2
OGG = 3
RAW = 4
OPUS = 0
VORBIS = 1
SIGNED_PCM = 2
UNSIGNED_PCM = 3
FLOAT_PCM = 4
ULAW = 5
ALAW = 6
RECORD_FULL_AUDIO = 0
RECORD_DETECTION_BLOBS = 1
RECORD_NOTHING = 2



_AUDIOFORMAT = _descriptor.Descriptor(
  name='AudioFormat',
  full_name='ai.cogneed.api.audio.AudioFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ext', full_name='ai.cogneed.api.audio.AudioFormat.ext', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.api.audio.AudioFormat.codec', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='ai.cogneed.api.audio.AudioFormat.sample_rate', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='ai.cogneed.api.audio.AudioFormat.channels', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_width', full_name='ai.cogneed.api.audio.AudioFormat.sample_width', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=243,
)


_DETECTIONRESPONSE = _descriptor.Descriptor(
  name='DetectionResponse',
  full_name='ai.cogneed.api.audio.DetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='ai.cogneed.api.audio.DetectionResponse.millisecond', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.audio.DetectionResponse.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=302,
)


_OPTIONALDETECTIONRESPONSE = _descriptor.Descriptor(
  name='OptionalDetectionResponse',
  full_name='ai.cogneed.api.audio.OptionalDetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection', full_name='ai.cogneed.api.audio.OptionalDetectionResponse.detection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=391,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.api.audio.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.AudioBlob.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=421,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='ai.cogneed.api.audio.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.api.audio.UserInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.audio.UserInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=463,
)

_AUDIOFORMAT.fields_by_name['ext'].enum_type = _AUDIOEXT
_AUDIOFORMAT.fields_by_name['codec'].enum_type = _AUDIOCODEC
_OPTIONALDETECTIONRESPONSE.fields_by_name['detection'].message_type = _DETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['AudioFormat'] = _AUDIOFORMAT
DESCRIPTOR.message_types_by_name['DetectionResponse'] = _DETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['OptionalDetectionResponse'] = _OPTIONALDETECTIONRESPONSE
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.enum_types_by_name['AudioExt'] = _AUDIOEXT
DESCRIPTOR.enum_types_by_name['AudioCodec'] = _AUDIOCODEC
DESCRIPTOR.enum_types_by_name['PersistenceConfig'] = _PERSISTENCECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioFormat = _reflection.GeneratedProtocolMessageType('AudioFormat', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOFORMAT,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.AudioFormat)
  ))
_sym_db.RegisterMessage(AudioFormat)

DetectionResponse = _reflection.GeneratedProtocolMessageType('DetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _DETECTIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.DetectionResponse)
  ))
_sym_db.RegisterMessage(DetectionResponse)

OptionalDetectionResponse = _reflection.GeneratedProtocolMessageType('OptionalDetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _OPTIONALDETECTIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.OptionalDetectionResponse)
  ))
_sym_db.RegisterMessage(OptionalDetectionResponse)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINFO,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.common_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.UserInfo)
  ))
_sym_db.RegisterMessage(UserInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
