# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/stream/audio_stream.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.audio import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/stream/audio_stream.proto',
  package='ai.cogneed.api.audio.stream',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.audio.streamP\001'),
  serialized_pb=_b('\n=cogneed-protos/ai/cogneed/api/audio/stream/audio_stream.proto\x12\x1b\x61i.cogneed.api.audio.stream\x1a*cogneed-protos/ai/cogneed/api/common.proto\x1a\x30\x63ogneed-protos/ai/cogneed/api/audio/common.proto\"7\n\x13InitSessionResponse\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\t\",\n\tModelInfo\x12\r\n\x05major\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"\x94\x02\n\x10SendAudioRequest\x12\x37\n\x0c\x61udio_format\x18\x01 \x01(\x0b\x32!.ai.cogneed.api.audio.AudioFormat\x12\x43\n\x12persistence_config\x18\x02 \x01(\x0e\x32\'.ai.cogneed.api.audio.PersistenceConfig\x12:\n\nmodel_info\x18\x03 \x01(\x0b\x32&.ai.cogneed.api.audio.stream.ModelInfo\x12\x11\n\tcall_uuid\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x12\x12\n\nblob_index\x18\x06 \x01(\x03\x12\x0e\n\x06millis\x18\x07 \x01(\x03\"&\n\x11\x45ndSessionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t2\xbd\x02\n\x12StreamAudioService\x12_\n\x0bInitSession\x12\x1e.ai.cogneed.api.audio.UserInfo\x1a\x30.ai.cogneed.api.audio.stream.InitSessionResponse\x12k\n\tSendAudio\x12-.ai.cogneed.api.audio.stream.SendAudioRequest\x1a/.ai.cogneed.api.audio.OptionalDetectionResponse\x12Y\n\nEndSession\x12..ai.cogneed.api.audio.stream.EndSessionRequest\x1a\x1b.ai.cogneed.api.AckResponseB\x1f\n\x1b\x61i.cogneed.api.audio.streamP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2.DESCRIPTOR,])




_INITSESSIONRESPONSE = _descriptor.Descriptor(
  name='InitSessionResponse',
  full_name='ai.cogneed.api.audio.stream.InitSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.stream.InitSessionResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.stream.InitSessionResponse.major', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=243,
)


_MODELINFO = _descriptor.Descriptor(
  name='ModelInfo',
  full_name='ai.cogneed.api.audio.stream.ModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.audio.stream.ModelInfo.major', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.audio.stream.ModelInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=289,
)


_SENDAUDIOREQUEST = _descriptor.Descriptor(
  name='SendAudioRequest',
  full_name='ai.cogneed.api.audio.stream.SendAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_format', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.audio_format', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.persistence_config', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_info', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.model_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.call_uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.blob_index', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='millis', full_name='ai.cogneed.api.audio.stream.SendAudioRequest.millis', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=568,
)


_ENDSESSIONREQUEST = _descriptor.Descriptor(
  name='EndSessionRequest',
  full_name='ai.cogneed.api.audio.stream.EndSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.stream.EndSessionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=608,
)

_SENDAUDIOREQUEST.fields_by_name['audio_format'].message_type = cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._AUDIOFORMAT
_SENDAUDIOREQUEST.fields_by_name['persistence_config'].enum_type = cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._PERSISTENCECONFIG
_SENDAUDIOREQUEST.fields_by_name['model_info'].message_type = _MODELINFO
DESCRIPTOR.message_types_by_name['InitSessionResponse'] = _INITSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ModelInfo'] = _MODELINFO
DESCRIPTOR.message_types_by_name['SendAudioRequest'] = _SENDAUDIOREQUEST
DESCRIPTOR.message_types_by_name['EndSessionRequest'] = _ENDSESSIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InitSessionResponse = _reflection.GeneratedProtocolMessageType('InitSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.InitSessionResponse)
  ))
_sym_db.RegisterMessage(InitSessionResponse)

ModelInfo = _reflection.GeneratedProtocolMessageType('ModelInfo', (_message.Message,), dict(
  DESCRIPTOR = _MODELINFO,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.ModelInfo)
  ))
_sym_db.RegisterMessage(ModelInfo)

SendAudioRequest = _reflection.GeneratedProtocolMessageType('SendAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDAUDIOREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.SendAudioRequest)
  ))
_sym_db.RegisterMessage(SendAudioRequest)

EndSessionRequest = _reflection.GeneratedProtocolMessageType('EndSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.stream.audio_stream_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.stream.EndSessionRequest)
  ))
_sym_db.RegisterMessage(EndSessionRequest)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.api.audio.stream.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=611,
  serialized_end=928,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitSession',
    full_name='ai.cogneed.api.audio.stream.StreamAudioService.InitSession',
    index=0,
    containing_service=None,
    input_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._USERINFO,
    output_type=_INITSESSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendAudio',
    full_name='ai.cogneed.api.audio.stream.StreamAudioService.SendAudio',
    index=1,
    containing_service=None,
    input_type=_SENDAUDIOREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_audio_dot_common__pb2._OPTIONALDETECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EndSession',
    full_name='ai.cogneed.api.audio.stream.StreamAudioService.EndSession',
    index=2,
    containing_service=None,
    input_type=_ENDSESSIONREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
