# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/detect/detect.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/detect/detect.proto',
  package='ai.cogneed.api.audio.detect',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.audio.detectP\001'),
  serialized_pb=_b('\n7cogneed-protos/ai/cogneed/api/audio/detect/detect.proto\x12\x1b\x61i.cogneed.api.audio.detect\x1a*cogneed-protos/ai/cogneed/api/common.proto\"C\n\tAudioBlob\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\nblob_index\x18\x03 \x01(\x03\"\x82\x01\n\tDetection\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x11\n\tcall_uuid\x18\x02 \x01(\t\x12\x15\n\ruse_case_uuid\x18\x03 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x04 \x01(\t\x12\x12\n\nblob_index\x18\t \x01(\x05\x12\x13\n\x0bwindow_size\x18\n \x01(\x05\x32\xbb\x01\n\rDetectService\x12R\n\x0bPersistBlob\x12&.ai.cogneed.api.audio.detect.AudioBlob\x1a\x1b.ai.cogneed.api.AckResponse\x12V\n\x0f\x43reateDetection\x12&.ai.cogneed.api.audio.detect.Detection\x1a\x1b.ai.cogneed.api.AckResponseB\x1f\n\x1b\x61i.cogneed.api.audio.detectP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.api.audio.detect.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.detect.AudioBlob.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.detect.AudioBlob.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.detect.AudioBlob.blob_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=199,
)


_DETECTION = _descriptor.Descriptor(
  name='Detection',
  full_name='ai.cogneed.api.audio.detect.Detection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.audio.detect.Detection.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.detect.Detection.call_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.audio.detect.Detection.use_case_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.audio.detect.Detection.keyword_uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.detect.Detection.blob_index', index=4,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='window_size', full_name='ai.cogneed.api.audio.detect.Detection.window_size', index=5,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=332,
)

DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['Detection'] = _DETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.detect.detect_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.detect.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

Detection = _reflection.GeneratedProtocolMessageType('Detection', (_message.Message,), dict(
  DESCRIPTOR = _DETECTION,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.detect.detect_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.detect.Detection)
  ))
_sym_db.RegisterMessage(Detection)


DESCRIPTOR._options = None

_DETECTSERVICE = _descriptor.ServiceDescriptor(
  name='DetectService',
  full_name='ai.cogneed.api.audio.detect.DetectService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=335,
  serialized_end=522,
  methods=[
  _descriptor.MethodDescriptor(
    name='PersistBlob',
    full_name='ai.cogneed.api.audio.detect.DetectService.PersistBlob',
    index=0,
    containing_service=None,
    input_type=_AUDIOBLOB,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDetection',
    full_name='ai.cogneed.api.audio.detect.DetectService.CreateDetection',
    index=1,
    containing_service=None,
    input_type=_DETECTION,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DETECTSERVICE)

DESCRIPTOR.services_by_name['DetectService'] = _DETECTSERVICE

# @@protoc_insertion_point(module_scope)
