# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/audio/recorder/recorder.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/audio/recorder/recorder.proto',
  package='ai.cogneed.api.audio.recorder',
  syntax='proto3',
  serialized_options=_b('\n\035ai.cogneed.api.audio.recorderP\001'),
  serialized_pb=_b('\n;cogneed-protos/ai/cogneed/api/audio/recorder/recorder.proto\x12\x1d\x61i.cogneed.api.audio.recorder\x1a*cogneed-protos/ai/cogneed/api/common.proto\"B\n\rRecordRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\nblob_index\x18\x03 \x01(\x03\"\"\n\x12\x43onsolidateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t2\xc3\x01\n\rRecordService\x12S\n\x06Record\x12,.ai.cogneed.api.audio.recorder.RecordRequest\x1a\x1b.ai.cogneed.api.AckResponse\x12]\n\x0b\x43onsolidate\x12\x31.ai.cogneed.api.audio.recorder.ConsolidateRequest\x1a\x1b.ai.cogneed.api.AckResponseB!\n\x1d\x61i.cogneed.api.audio.recorderP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_RECORDREQUEST = _descriptor.Descriptor(
  name='RecordRequest',
  full_name='ai.cogneed.api.audio.recorder.RecordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.audio.recorder.RecordRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.recorder.RecordRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.audio.recorder.RecordRequest.blob_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=204,
)


_CONSOLIDATEREQUEST = _descriptor.Descriptor(
  name='ConsolidateRequest',
  full_name='ai.cogneed.api.audio.recorder.ConsolidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.audio.recorder.ConsolidateRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=240,
)

DESCRIPTOR.message_types_by_name['RecordRequest'] = _RECORDREQUEST
DESCRIPTOR.message_types_by_name['ConsolidateRequest'] = _CONSOLIDATEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecordRequest = _reflection.GeneratedProtocolMessageType('RecordRequest', (_message.Message,), dict(
  DESCRIPTOR = _RECORDREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.recorder.recorder_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.recorder.RecordRequest)
  ))
_sym_db.RegisterMessage(RecordRequest)

ConsolidateRequest = _reflection.GeneratedProtocolMessageType('ConsolidateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSOLIDATEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.audio.recorder.recorder_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.recorder.ConsolidateRequest)
  ))
_sym_db.RegisterMessage(ConsolidateRequest)


DESCRIPTOR._options = None

_RECORDSERVICE = _descriptor.ServiceDescriptor(
  name='RecordService',
  full_name='ai.cogneed.api.audio.recorder.RecordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=243,
  serialized_end=438,
  methods=[
  _descriptor.MethodDescriptor(
    name='Record',
    full_name='ai.cogneed.api.audio.recorder.RecordService.Record',
    index=0,
    containing_service=None,
    input_type=_RECORDREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Consolidate',
    full_name='ai.cogneed.api.audio.recorder.RecordService.Consolidate',
    index=1,
    containing_service=None,
    input_type=_CONSOLIDATEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECORDSERVICE)

DESCRIPTOR.services_by_name['RecordService'] = _RECORDSERVICE

# @@protoc_insertion_point(module_scope)
