# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/predict/labelmapper/labelmapper.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/predict/labelmapper/labelmapper.proto',
  package='ai.cogneed.api.predict.labelmapper',
  syntax='proto3',
  serialized_options=_b('\n\"ai.cogneed.api.predict.labelmapperP\001'),
  serialized_pb=_b('\nCcogneed-protos/ai/cogneed/api/predict/labelmapper/labelmapper.proto\x12\"ai.cogneed.api.predict.labelmapper\"O\n\x0e\x43onvertRequest\x12\x18\n\x10prediction_index\x18\x01 \x01(\x05\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x03\"\'\n\x0f\x43onvertResponse\x12\x14\n\x0ckeyword_uuid\x18\x01 \x01(\t2\x88\x01\n\x12LabelMapperService\x12r\n\x07\x43onvert\x12\x32.ai.cogneed.api.predict.labelmapper.ConvertRequest\x1a\x33.ai.cogneed.api.predict.labelmapper.ConvertResponseB&\n\"ai.cogneed.api.predict.labelmapperP\x01\x62\x06proto3')
)




_CONVERTREQUEST = _descriptor.Descriptor(
  name='ConvertRequest',
  full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_index', full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest.prediction_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest.model_name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.cogneed.api.predict.labelmapper.ConvertRequest.version', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=186,
)


_CONVERTRESPONSE = _descriptor.Descriptor(
  name='ConvertResponse',
  full_name='ai.cogneed.api.predict.labelmapper.ConvertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.predict.labelmapper.ConvertResponse.keyword_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=227,
)

DESCRIPTOR.message_types_by_name['ConvertRequest'] = _CONVERTREQUEST
DESCRIPTOR.message_types_by_name['ConvertResponse'] = _CONVERTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConvertRequest = _reflection.GeneratedProtocolMessageType('ConvertRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONVERTREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.labelmapper.labelmapper_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.labelmapper.ConvertRequest)
  ))
_sym_db.RegisterMessage(ConvertRequest)

ConvertResponse = _reflection.GeneratedProtocolMessageType('ConvertResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONVERTRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.labelmapper.labelmapper_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.labelmapper.ConvertResponse)
  ))
_sym_db.RegisterMessage(ConvertResponse)


DESCRIPTOR._options = None

_LABELMAPPERSERVICE = _descriptor.ServiceDescriptor(
  name='LabelMapperService',
  full_name='ai.cogneed.api.predict.labelmapper.LabelMapperService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=230,
  serialized_end=366,
  methods=[
  _descriptor.MethodDescriptor(
    name='Convert',
    full_name='ai.cogneed.api.predict.labelmapper.LabelMapperService.Convert',
    index=0,
    containing_service=None,
    input_type=_CONVERTREQUEST,
    output_type=_CONVERTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_LABELMAPPERSERVICE)

DESCRIPTOR.services_by_name['LabelMapperService'] = _LABELMAPPERSERVICE

# @@protoc_insertion_point(module_scope)
